Crate ree

Crate ree 

A fast terminal reset for macOS and Linux.

ree repairs the kernel TTY state and resets the attached terminal emulator without linking to ncurses.

Enums

Error
An error that stopped ree from resetting the terminal.

Functions

reset
Repair the kernel TTY state and reset the attached terminal emulator.