reset

Function reset 

pub fn reset() -> Result<(), Error>
Repair the kernel TTY state and reset the attached terminal emulator.

Errors

Returns Error when no terminal is available, the process is a background job, terminal state cannot be changed, or the terminfo entry cannot be read.

Examples

ree::reset()?;